<?xml version="1.0" encoding="UTF-8"?>
<!--
	XSLT for transforming NewsCodes provided as an IPTC G2 Knowledge Item into a RDF/XML+SKOS instance.
	(c) 2011, IPTC - www.iptc.org
	See license for using this file at: http://www.iptc.org/goto?license
	Author: Michael Steidl, IPTC
	Version:
	v3: 2011-03-28
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://iptc.org/std/nar/2006-10-01/" xmlns:nar="http://iptc.org/std/nar/2006-10-01/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:skos="http://www.w3.org/2004/02/skos/core#" xmlns:owl="http://www.w3.org/2002/07/owl#">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:skos="http://www.w3.org/2004/02/skos/core#">
			<xsl:apply-templates select="//nar:conceptSet" mode="SchemeList"/>
			<xsl:apply-templates select="//nar:conceptSet" mode="Concepts"/>
		</rdf:RDF>
	</xsl:template>
	<!-- ********* Template to create the SKOS Concept Scheme class -->
	<xsl:template match="nar:conceptSet" mode="SchemeList">
		<rdf:Description rdf:about="http://cv.iptc.org/newscodes/mediatopic/">
			<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#ConceptScheme"/>
			<!-- the selection below builds on the style of IPTC-delivered KIs to provide broader elements for all children in a taxonomy tree
					Thus the concepts with no broader elements are the concepts at the top level -->
			<xsl:for-each select="nar:concept[count(nar:broader) = 0]">
				<skos:HasTopConcept>
					<rdf:Description>
						<xsl:attribute name="rdf:about">http://cv.iptc.org/newscodes/mediatopic/<xsl:value-of select="substring-after(nar:conceptId/@qcode,':')"></xsl:value-of></xsl:attribute>
						<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
					</rdf:Description>
				</skos:HasTopConcept>
			</xsl:for-each>
		</rdf:Description>
	</xsl:template>
	<!-- ********* Template to create individual SKOS Concept classes -->
	<xsl:template match="nar:conceptSet" mode="Concepts">
		<xsl:for-each select="nar:concept">
			<rdf:Description>
				<xsl:attribute name="rdf:about">http://cv.iptc.org/newscodes/mediatopic/<xsl:value-of select="substring-after(nar:conceptId/@qcode,':')"/></xsl:attribute>
				<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
				<xsl:for-each select="nar:name">
					<skos:prefLabel>
						<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
						<xsl:value-of select="."/>
					</skos:prefLabel>
				</xsl:for-each>
				<xsl:for-each select="nar:definition">
					<skos:definition>
						<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
						<xsl:value-of select="."/>
					</skos:definition>
				</xsl:for-each>
				<skos:inScheme rdf:resource="http://cv.iptc.org/newscodes/mediatopic/"/>
				<!-- create broader relationships: they exist as broader elements in the IPTC-delivered KIs -->
				<xsl:comment>Broader Relationships</xsl:comment>
				<xsl:for-each select="nar:broader">
					<skos:broaderTransitive>
						<rdf:Description>
							<xsl:attribute name="rdf:about">http://cv.iptc.org/newscodes/mediatopic/<xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
							<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
						</rdf:Description>
					</skos:broaderTransitive>
				</xsl:for-each>
				<!-- create narrower relationships: inverted selection: narrower concepts are concepts with a broader element referring to "this" concept -->
				<xsl:comment>Narrower Relationships</xsl:comment>
				<xsl:variable name="thisQCode"><xsl:value-of select="./nar:conceptId/@qcode" /></xsl:variable>
				<xsl:for-each select="../nar:concept[nar:broader/@qcode=$thisQCode]">
					<skos:narrower>
						<rdf:Description>
							<xsl:attribute name="rdf:about">http://cv.iptc.org/newscodes/mediatopic/<xsl:value-of select="substring-after(nar:conceptId/@qcode,':')"/></xsl:attribute>
							<rdf:type rdf:resource="http://www.w3.org/2004/02/skos/core#Concept"/>
						</rdf:Description>
					</skos:narrower>
				</xsl:for-each>
				<!-- create SKOS mapping relationships -->
				<xsl:comment>SKOS Mapping Relationships</xsl:comment>
				<xsl:for-each select="nar:related">
					<xsl:choose>
						<xsl:when test="@rel='skos:exactMatch' ">
						<skos:exactMatch>
						<xsl:attribute name="rdf:resource">http://cv.iptc.org/newscodes/subjectcode/<xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:exactMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:closeMatch' ">
						<skos:closeMatch>
						<xsl:attribute name="rdf:resource">http://cv.iptc.org/newscodes/subjectcode/<xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:closeMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:broadMatch' ">
						<skos:broadMatch>
						<xsl:attribute name="rdf:resource">http://cv.iptc.org/newscodes/subjectcode/<xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:broadMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:narrowMatch' ">
						<skos:narrowMatch>
						<xsl:attribute name="rdf:resource">http://cv.iptc.org/newscodes/subjectcode/<xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:narrowMatch>
						</xsl:when>
						<xsl:when test="@rel='skos:releatedMatch' ">
						<skos:relatedMatch>
						<xsl:attribute name="rdf:resource">http://cv.iptc.org/newscodes/subjectcode/<xsl:value-of select="substring-after(@qcode,':')"/></xsl:attribute>
						</skos:relatedMatch>
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>
			</rdf:Description>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
